@@ -2,7 +2,7 @@
 #
 # Testfile for ipv6calc
 #
-# Version:     $Id: test_ipv6calc.sh,v 0.15 2001/03/12 $
+# Version:     $Id: test_ipv6calc.sh,v 0.16 2001/03/13 $
 #
 # Author:      Peter Bieringer <pb@bieringer.de>
 #
@@ -10,7 +10,7 @@
 #
 
 
-function testscenarios () {
+testscenarios() {
 # Command													Expected result (no space between "=" and result)
 cat <<END
 --addr_to_ip6int 3ffe:400:100:f101::1								=1.0.0.0.0.0.0.0.0.0.0.0.0.0.0.0.1.0.1.f.0.0.1.0.0.0.4.0.e.f.f.3.ip6.int
